@@ -4,7 +4,6 @@ use Moose;
 use Moose::Autobox;
 use DateTime;
 use Sys::Hostname qw/hostname/;
-use XML::OPML::SimpleGen;
 
 use namespace::autoclean;
 
@@ -13,8 +12,6 @@ BEGIN { extends 'Gitalist::Controller' }
 sub opml : Chained('/base') Args(0) {
     my ($self, $c) = @_;
 
-    my $opml = XML::OPML::SimpleGen->new();
-
     $c->stash(
         title => lc(hostname()) . ' - ' . blessed($c)->config->{name},
         Repositories => $c->model()->repositories,
